@@ -32,7 +32,7 @@ use crate::font::FormattedTextBlock;
 use crate::font_cache::{GlyphCache, GlyphCacheInterface};
 use crate::glwrapper::*;
 use crate::image::{ImageDataType, ImageHandle, ImageSmoothingMode};
-use crate::Rectangle;
+use crate::{Polygon, Rectangle};
 
 struct AttributeBuffers
 {
@@ -768,6 +768,24 @@ impl Renderer2D
         }
     }
 
+    #[inline]
+    pub(crate) fn draw_polygon<V: Into<Vector2<f32>>>(
+        &mut self,
+        polygon: &Polygon,
+        offset: V,
+        color: Color
+    )
+    {
+        let color = [color; 3];
+        let offset = offset.into();
+
+        for triangle in polygon.triangles.iter() {
+            let triangle = triangle.map(|vertex| vertex + offset);
+
+            self.draw_triangle_three_color(triangle, color);
+        }
+    }
+
     #[inline]
     pub(crate) fn draw_triangle_three_color(
         &mut self,
